//	--------------------------------------------------------------------------
//	A generic scene file for rendering the #include files for the Uniform Polyhedra.
//	By Russell Towle, April, 2002.
//
//	The data and numbering of the uniform polyhedra are derived from
//	Roman Maeder's Mathematica notebooks.
//
//	--------------------------------------------------------------------------
//	modified by louis bellotto, march 2004.
//	--------------------------------------------------------------------------
// this modified version allow you to render all or range of polyhedra and,
//	for each one, its name is displayed onto the image.
//
//	* use clock settings to render all or party of polyhedra :
//		- turn clock on
//		- set "Subset Start" to the first polyhedre number (1..80)
//		- set "Sunset End" to the last polyhedre number (1..80)
//
// * if "clock" is not set, only "#01.inc" polyhedre is render.
//
// * in each file "#xx.inc", a new varaible "polyName" is declared.
//		this name is displayed in the image. to do this, i use the
//		new (pov 3.5/megapov 1.0) include file "screen.inc".
//
// * other minor change :
//		- textures are directly defined in this file.
//		- the two light sources are now white.
//		- a checkred texture is use for the plane.
//
//	* render images at 4/3 ratio : 320x240, 640x480,...
//
//	--------------------------------------------------------------------------
//	you can find the original package at :
// 	http://mac.povray.org/download/binaries/uniformia/uniform.html
//	--------------------------------------------------------------------------
#version unofficial MegaPov 1.0;




//	--------------------------------------------------------------------------
//	--- INCLUDES -------------------------------------------------------------
//	--------------------------------------------------------------------------
#include "colors.inc"
#include "screen.inc"




//	--------------------------------------------------------------------------
//	--- GLOBAL SETTINGS ------------------------------------------------------
//	--------------------------------------------------------------------------
global_settings {
	assumed_gamma 1.8
	max_trace_level 10
	}

#default { texture { pigment {color rgb <1,1,1>} finish {phong 0.1 ambient 0.2 diffuse .6} }}

#declare R1 = 0.0750;		//	Balls radius
#declare R2 = 0.0375; 	//	Sticks radius




//	--------------------------------------------------------------------------
//	--- SCENE ----------------------------------------------------------------
//	--------------------------------------------------------------------------
#declare cameraLocation = <0, -5, 12>;
#declare cameraLookAt = <0, 0, 0>;
#declare cameraAngle = 28;

Set_Camera(cameraLocation, cameraLookAt, cameraAngle)
Set_Camera_Aspect(4,3)

light_source {
	<0, 0, 100>
	color White*0.50
	}

light_source {
	<12, -33, 44>
	color White*0.50
	}

plane{
	z,-3
	pigment  {
		checker White, White*0.90 scale 2
		}
	finish {
		specular 1
		roughness 0.001
		reflection 0.05
		}
	}
	
sky_sphere {
	pigment {
	gradient z
		color_map {
			[ 0.000 rgbft <0.0, 0.0, 0.0, 0.0, 0.0> ]	//black
			[ 1.000 rgbft <1.0, 1.0, 1.0, 0.0, 0.0> ]	//white
			}
		}
	}




//	--------------------------------------------------------------------------
//	--- TEXTURES -------------------------------------------------------------
//	--------------------------------------------------------------------------
#declare rodsTexture = texture {
	pigment {
		color rgb <0.94, 0.93, 0.80>
		}
	finish {
		ambient 0.35
		brilliance 2
		diffuse 0.3
		metallic
		specular 0.80
		roughness 1/20
		reflection 0.1
		}
	}

#declare ballsTexture = texture {
	pigment {
		rgb <0.85, 0.85, 0.10>
		}
	finish {
		metallic
		ambient 0.2
		diffuse 0.7
		brilliance 6
		reflection 0.25
		phong 0.75
		phong_size 80
		}
	}

#declare facesTexture = texture {
	pigment { rgbf <0.885939, 0.639963, 1.000000, 0.5> }
	finish { brilliance 1.0 specular 1.0 metallic 1.0 }
	}




//	--------------------------------------------------------------------------
//	--- ALL UNIFORMS POLYHEDRA -----------------------------------------------
//	--------------------------------------------------------------------------
#if (!clock_on)
	#declare fileNum="01";
#else
	#declare fileNum = str(frame_number,0,0);
	#if (frame_number<10) #set fileNum = concat("0",fileNum); #end
#end

#declare fileName = concat("#",fileNum,".inc");
#debug concat("\ninclude ",fileName,"\n")

#include fileName

object { RODS texture{ rodsTexture} }
object { BALLS texture{ ballsTexture } }
object { FACES texture{ facesTexture } }

#declare titleObject = text {
	ttf "crystal.ttf", polyName, 0.01, <0,0>
	scale 0.06
	pigment { color <0.0, 0.0, 0.0> }
	finish { ambient 1 diffuse 0 }
	}

Screen_Object ( titleObject, <0,1>, <0.04,0.02>, true, 0.01 )


